from setuptools import setup, find_packages

setup(
    name="metapyt",
    version="1.0.9",
    description="This is a library with encryption. I created it to surprise my friend for his birthday. Please don't delete it.",
    author="eropens",
    author_email="eropn313@gmail.com",
    packages=find_packages(),
    install_requires=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent"
    ],
    python_requires=">=3.6",
)